<?php

namespace Drupal\elasticsearch_connector_ngram_analyzer;

use Drupal\elasticsearch_connector\Analyser\AnalyserManager;

/**
 * Service for managing Elasticsearch analyzers.
 */
final class AnalyzerService implements AnalyzerServiceInterface {

  /**
   * Constructs an analyzerService object.
   */
  public function __construct(
    private readonly AnalyserManager $analyzerManager,
  ) {}

  /**
   * Gets the analyzer definition for a given plugin ID.
   *
   * @param string $plugin_id
   *   The plugin ID.
   *
   * @return array
   *   The analyzer definition.
   */
  public function getAnalyzerDefinition($plugin_id) {
    $plugin = $this->analyzerManager->createInstance($plugin_id);
    return $plugin->getAnalyzerDefinition();
  }

  /**
   * {@inheritdoc}
   */
  public function getTokenizerDefinition($plugin_id) {
    $plugin = $this->analyzerManager->createInstance($plugin_id);
    return $plugin->getTokenizerDefinition();
  }

  /**
   * Gets the filter definition for a given plugin ID.
   *
   * @param string $plugin_id
   *   The plugin ID.
   *
   * @return array
   *   The filter definition.
   */
  public function getFilterDefinition($plugin_id) {
    $plugin = $this->analyzerManager->createInstance($plugin_id);
    return $plugin->getFilterDefinition();
  }

}
