<?php

namespace Drupal\elasticsearch_connector_ngram_analyzer\EventSubscriber;

use Drupal\elasticsearch_connector\Event\AlterSettingsEvent;
use Drupal\elasticsearch_connector_ngram_analyzer\AnalyzerServiceInterface;
use Drupal\search_api\DataType\DataTypePluginManager;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * This is the event subscriber for the AlterSettingsEvent.
 */
final class AlterSettingsSubscriber implements EventSubscriberInterface {

  /**
   * Constructs an AlterSettingsSubscriber object.
   */
  public function __construct(
    private readonly AnalyzerServiceInterface $analyzerService,
    private readonly DataTypePluginManager $searchApiDataType,
  ) {}

  /**
   * Reacts to the AlterSettingsEvent.
   *
   * @param \Drupal\elasticsearch_connector\Event\AlterSettingsEvent $event
   *   The AlterSettingsEvent.
   */
  public function onAlterSettings(AlterSettingsEvent $event) {
    $settings = $event->getSettings();

    // Ngram tokenizer settings.
    $settings['analysis']['analyzer']['ngram_analyzer'] = $this->analyzerService
      ->getAnalyzerDefinition('ngram_analyzer');
    $settings['analysis']['tokenizer']['es_ngram'] = $this->analyzerService
      ->getTokenizerDefinition('ngram_analyzer');

    $event->setSettings($settings);
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      AlterSettingsEvent::class => 'onAlterSettings',
    ];
  }

}
