<?php

namespace Drupal\elasticsearch_connector_ngram_analyzer\EventSubscriber;

use Drupal\Component\EventDispatcher\Event;
use Drupal\elasticsearch_connector\Event\FieldMappingEvent;
use Drupal\search_api\DataType\DataTypePluginManager;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Subscribes to the Search API mapping field types event.
 */
final class MappingFieldTypesEventSubscriber implements EventSubscriberInterface {

  /**
   * Constructs a MappingFieldTypesEventSubscriber object.
   */
  public function __construct(
    private readonly DataTypePluginManager $dataTypePluginManager,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[FieldMappingEvent::class] = [
      'onFieldMapping',
    ];

    return $events;
  }

  /**
   * Reacts to the mapping field types event.
   *
   * @param \Drupal\elasticsearch_connector\Event\FieldMappingEvent $event
   *   The mapping field types event.
   */
  public function onFieldMapping(Event $event) {
    /** @var \Drupal\search_api\Item\FieldInterface $field */
    $field = $event->getField();
    $field_type = $field->getType();
    if ($field_type !== 'text_ngram') {
      return;
    }

    // Set the field type to 'text' and the analyzer to 'ngram_analyzer'.
    $params = [
      'type' => 'text',
      'analyzer' => 'ngram_analyzer',
      'fields' => [
        "keyword" => [
          "type" => 'keyword',
          'ignore_above' => 256,
        ],
      ],
    ];

    $event->setParam($params);
  }

}
