<?php

namespace Drupal\elasticsearch_connector_ngram_analyzer\EventSubscriber;

use Drupal\Component\EventDispatcher\Event;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\elasticsearch_connector\Event\QueryParamsEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * This is the event subscriber for the QueryParamsEvent.
 */
final class QueryParamsEventSubscriber implements EventSubscriberInterface {

  /**
   * Constructs a QueryParamsEventSubscriber object.
   */
  public function __construct(
    private readonly RouteMatchInterface $routeMatch,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events[QueryParamsEvent::class] = [
      'onElasticsearchBuildQuery',
    ];

    return $events;
  }

  /**
   * Reacts to the QueryParamsEvent.
   *
   * @param \Drupal\elasticsearch_connector\Event\QueryParamsEvent $event
   *   The QueryParamsEvent.
   */
  public function onElasticsearchBuildQuery(Event $event): void {
    $params = $event->getParams();
    if (isset($params['body']['query']['bool']['must']['query_string'])) {
      $query_string = &$params['body']['query']['bool']['must']['query_string'];
    }
    elseif (isset($params['body']['query']['query_string'])) {
      $query_string = &$params['body']['query']['query_string'];
    }
    if (!isset($query_string)) {
      return;
    }

    // Get keys from query.
    $keys = $query_string['query'] ?? '';
    // Remove not needed words and characters.
    $clean_keys = preg_replace('/( AND|~)/', '', $keys);
    if ($keys !== $clean_keys) {
      // Set cleaned keys back to query.
      $query_string['query'] = $clean_keys;
    }
    // Add default operator.
    $query_string['default_operator'] = 'AND';

    $event->setParams($params);
  }

}
